pub struct QueryStats { /* private fields */ }Expand description
Statistics for query planning decisions.
Implementations
Sourceimpl QueryStats
impl QueryStats
Sourcepub fn update_graph_selectivity(&self, matched: u64, total: u64)
pub fn update_graph_selectivity(&self, matched: u64, total: u64)
Updates graph selectivity estimate.
Sourcepub fn graph_selectivity(&self) -> f64
pub fn graph_selectivity(&self) -> f64
Gets the current graph selectivity estimate (0.0-1.0).
Sourcepub fn update_vector_latency(&self, latency_us: u64)
pub fn update_vector_latency(&self, latency_us: u64)
Updates average vector search latency using exponential moving average.
Uses EMA with α=0.1 for thread-safe updates without race conditions. EMA formula: new_avg = α * latency + (1-α) * old_avg This avoids the race condition in running average calculations.
Sourcepub fn update_graph_latency(&self, latency_us: u64)
pub fn update_graph_latency(&self, latency_us: u64)
Updates average graph traversal latency using exponential moving average.
Uses EMA with α=0.1 for thread-safe updates without race conditions. This ensures accurate statistics for query planning decisions.
Sourcepub fn avg_vector_latency_us(&self) -> u64
pub fn avg_vector_latency_us(&self) -> u64
Gets the average vector latency in microseconds.
Sourcepub fn avg_graph_latency_us(&self) -> u64
pub fn avg_graph_latency_us(&self) -> u64
Gets the average graph latency in microseconds.
Sourcepub fn vector_query_count(&self) -> u64
pub fn vector_query_count(&self) -> u64
Gets the total number of vector queries.
Sourcepub fn graph_query_count(&self) -> u64
pub fn graph_query_count(&self) -> u64
Gets the total number of graph queries.